@@ -1,22 +1,10 @@
-// This file is part of the Rust library `subparse`.
-//
-// Copyright (C) 2017 kaegi
-//
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU Lesser General Public License for more details.
-//
-// You should have received a copy of the GNU Lesser General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// This Source Code Form is subject to the terms of the Mozilla Public
+// License, v. 2.0. If a copy of the MPL was not distributed with this
+// file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 
-use {ParseSubtitleString, SubtitleEntry, SubtitleFile};
+
+use {SubtitleEntry, SubtitleFile};
 use errors::Result as SubtitleParserResult;
 use formats::common::*;
 use timetypes::{TimePoint, TimeSpan};
@@ -123,9 +111,10 @@ impl SsaFieldsInfo {
 // ////////////////////////////////////////////////////////////////////////////////////////////////
 // SSA parser
 
-impl ParseSubtitleString for SsaFile {
-    fn parse_from_string(s: String) -> SubtitleParserResult<SsaFile> {
-        match Self::parse_inner(s) {
+impl SsaFile {
+    /// Parse a `.ssa` subtitle string to `SsaFile`.
+    pub fn parse(s: &str) -> SubtitleParserResult<SsaFile> {
+        match Self::parse_inner(s.to_string()) {
             Ok(v) => Ok(v),
             Err(e) => Err(e.into()),
         }
@@ -180,10 +169,8 @@ impl SsaFile {
     fn parse_dialog_lines(fields_info: &SsaFieldsInfo, s: &str) -> Result<Vec<SsaFilePart>> {
         let mut result = Vec::new();
         let mut section_opt: Option<String> = None;
-        let lines_with_newl: Vec<(String, String)> = get_lines_non_destructive(s)
-            .map_err(|(line_num, err_str)| SsaLineParseError(line_num, err_str))?;
 
-        for (line_num, (line, newl)) in lines_with_newl.into_iter().enumerate() {
+        for (line_num, (line, newl)) in get_lines_non_destructive(s).into_iter().enumerate() {
             let trimmed_line = line.trim().to_string();
 
             // parse section headers like `[Events]`
