@@ -1,19 +1,7 @@
-// This file is part of the Rust library `subparse`.
-//
-// Copyright (C) 2017 kaegi
-//
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU Lesser General Public License for more details.
-//
-// You should have received a copy of the GNU Lesser General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// This Source Code Form is subject to the terms of the Mozilla Public
+// License, v. 2.0. If a copy of the MPL was not distributed with this
+// file, You can obtain one at http://mozilla.org/MPL/2.0/.
+
 #![deny(missing_docs,
         missing_debug_implementations, missing_copy_implementations,
         trivial_casts, trivial_numeric_casts,
@@ -23,7 +11,7 @@
 
 
 
-//! This crate provides a common interface for popular subtitle formats (`.srt`, `.ssa`, `.ass`, `.idx`).
+//! This crate provides a common interface for popular subtitle formats (`.srt`, `.ssa`, `.ass`, `.idx`, `.sub`).
 //!
 //! Files can be parsed, modified and saved again - some formats can be created from scratch.
 //! The focus is on non-destructive parsing, meaning that formatting and other information are preserved
@@ -32,6 +20,8 @@
 #[macro_use]
 extern crate error_chain;
 extern crate combine;
+extern crate vobsub;
+extern crate itertools;
 
 mod formats;
 
@@ -44,8 +34,11 @@ pub mod errors;
 pub use formats::srt::SrtFile;
 pub use formats::idx::IdxFile;
 pub use formats::ssa::SsaFile;
+pub use formats::vobsub::VobFile;
+pub use formats::microdvd::MdvdFile;
 pub use formats::SubtitleFormat;
-pub use formats::{get_subtitle_format_by_ending, get_subtitle_format_by_ending_err, parse_file_from_string};
+pub use formats::{get_subtitle_format, get_subtitle_format_by_ending, get_subtitle_format_by_ending_err, get_subtitle_format_err, parse_bytes,
+                  parse_str};
 
 use errors::*;
 use timetypes::TimeSpan;
@@ -76,39 +69,13 @@ pub trait SubtitleFile {
     fn to_data(&self) -> Result<Vec<u8>>;
 }
 
-/// This trait is implemented for all text subtitle file types which can be parsed from a string.
-///
-/// Note that most subtitles are in text format, but a few of them are in binary format.
-pub trait ParseSubtitleString: Sized {
-    /// Parse the subtitle from text.
-    fn parse_from_string(s: String) -> Result<Self>;
-}
-
-/// This trait is implemented for all subtitle files.
-///
-/// It is implemented for all types that implement `ParseSubtitleString`, by converting the bytes
-/// to a string (assuming utf-8 encoding).
-pub trait ParseSubtitle: Sized {
-    /// Parse the subtitle from bytes.
-    fn parse(b: &[u8]) -> Result<Self>;
-}
-
-impl<T> ParseSubtitle for T
-    where T: ParseSubtitleString
-{
-    /// Parse the subtitle from bytes.
-    fn parse(b: &[u8]) -> Result<Self> {
-        let s = String::from_utf8(b.to_vec())?;
-        Self::parse_from_string(s)
-    }
-}
-
 /// The data which can be read from/written to a subtitle file.
 #[derive(Debug)]
 pub struct SubtitleEntry {
     /// The duration for which the current subtitle will be shown.
     pub timespan: TimeSpan,
 
+    // TODO: to Vec<String>
     /// The text which will be shown in this subtitle. Be aware that
     /// for example VobSub files (and any other image based format)
     /// will have `None` as value.
